Name:           enzo
Version:        2.6.1
Release:        %mkrel 3
Summary:        An adaptive mesh refinement code for astrophysical calculations
License:        BSD
Group:          Sciences/Astronomy

URL:            https://enzo-project.org
Source0:        https://github.com/enzo-project/enzo-dev/archive/%{name}-%{version}.tar.gz
Patch0:         enzo-2.5-nosse.patch
Patch1:         enzo-2.6-mga-hdf5.patch
BuildRequires:  hdf5-devel
BuildRequires:  tcsh
BuildRequires:  openmpi-devel
BuildRequires:  makedepend
BuildRequires:  python3
BuildRequires:  mercurial

Requires:       openmpi

%description
Enzo is a community-developed adaptive mesh refinement simulation
code, designed for rich, multi-physics hydrodynamic astrophysical
calculations. Enzo is freely available, developed in the open, with a
strong support structure for assistance. Simulations conducted with
Enzo have been featured in numerous refereed journal articles, and it
is capable of running on computers from laptop to Top500.

%prep
%setup -q -n enzo-dev-%{name}-%{version}
%autopatch -p1

%build
%configure
pushd src/enzo
make dep
%make_build machine-linux-gnu
%ifarch %ix86 %{arm} aarch64
%make_build CFLAGS="%{optflags} -DNOSSE" \
            CXXFLAGS="%{optflags} -DNOSSE" \
            FFLAGS="%{optflags} -DNOSSE -fallow-argument-mismatch" \
            F90FLAGS="%{optflags} -DNOSSE -fallow-argument-mismatch" \
	    LDFLAGS="%{ldflags}"
%else
%make_build CFLAGS="%{optflags}" \
            CXXFLAGS="%{optflags}" \
            FFLAGS="%{optflags} -fallow-argument-mismatch" \
            F90FLAGS="%{optflags} -fallow-argument-mismatch" \
	    LDFLAGS="%{ldflags}"
%endif
popd
pushd src/inits
%make_build FFLAGS="%{optflags} -fallow-argument-mismatch"
popd
pushd src/ring
%make_build FFLAGS="%{optflags} -fallow-argument-mismatch"
popd

%install
%__mkdir_p %{buildroot}%{_bindir}
cp -p bin/*  %{buildroot}%{_bindir}

%files
%{_bindir}/enzo
%{_bindir}/np
%{_bindir}/find_conflicts
%{_bindir}/inits
%{_bindir}/pr_testing
%{_bindir}/update_path


%changelog
* Sat Jan 09 2021 daviddavid <daviddavid> 2.6.1-3.mga8
+ Revision: 1670048
- rebuild for new hdf5 1.10.7

* Tue Jun 09 2020 joequant <joequant> 2.6.1-2.mga8
+ Revision: 1591480
- update to gcc10
- fix for gcc10
- revert delete of enzo

* Fri Apr 17 2020 danf <danf> 2.6.1-1.mga8
+ Revision: 1568203
- Upgrade to ver. 2.6.1
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Jan 09 2019 zezinho <zezinho> 2.5-16.mga7
+ Revision: 1353756
- rebuild for openmpi abi change

* Thu Nov 08 2018 daviddavid <daviddavid> 2.5-15.mga7
+ Revision: 1328944
- rebuild for new hdf5 1.10.4

* Wed Oct 17 2018 pterjan <pterjan> 2.5-14.mga7
+ Revision: 1321884
- Add missing half of aarch64 patch
- Fix build on aarch64

* Sun Sep 23 2018 umeabot <umeabot> 2.5-12.mga7
+ Revision: 1297609
- Mageia 7 Mass Rebuild

* Fri Aug 17 2018 eatdirt <eatdirt> 2.5-11.mga7
+ Revision: 1252232
- Rebuild for new gfortran

* Sat Jul 14 2018 wally <wally> 2.5-10.mga7
+ Revision: 1243700
- add patch to fix build with glibc >= 2.26

* Fri May 18 2018 eatdirt <eatdirt> 2.5-9.mga7
+ Revision: 1230334
- Rebuild for new openmpi

* Mon Oct 09 2017 eatdirt <eatdirt> 2.5-8.mga7
+ Revision: 1170613
- Fix seed size array too small
- Rebuild for new openmpi
+ tv <tv>
- rebuild for new libgfortran

* Fri Dec 16 2016 pterjan <pterjan> 2.5-5.mga6
+ Revision: 1075597
- Workaround parallel make bug

* Fri Dec 16 2016 eatdirt <eatdirt> 2.5-4.mga6
+ Revision: 1075558
- Fix missing requires + try to fix arm built failures

* Thu Dec 15 2016 eatdirt <eatdirt> 2.5-2.mga6
+ Revision: 1075463
- Fix compilation failure on ix86 due to implicit sse instructions
- Upgrade to latest version 2.5

* Fri Dec 02 2016 tmb <tmb> 2.3-7.mga6
+ Revision: 1071626
- rebuild for new openmpi

* Sun Feb 14 2016 umeabot <umeabot> 2.3-6.mga6
+ Revision: 960024
- Mageia 6 Mass Rebuild

* Wed Sep 30 2015 daviddavid <daviddavid> 2.3-5.mga6
+ Revision: 885260
- rebuild for new openmpi 1.10.0

* Tue Jul 21 2015 daviddavid <daviddavid> 2.3-4.mga6
+ Revision: 855893
- rebuild with new hdf5

* Wed Oct 15 2014 umeabot <umeabot> 2.3-3.mga5
+ Revision: 742750
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Thu Jul 03 2014 eatdirt <eatdirt> 2.3-1.mga5
+ Revision: 642662
- Upgrade to version 2.3

* Sat Oct 19 2013 umeabot <umeabot> 2.2-2.mga4
+ Revision: 530643
- Mageia 4 Mass Rebuild

* Fri Jul 26 2013 joequant <joequant> 2.2-1.mga4
+ Revision: 458611
- remove period from summary
- fix build requires
- spec cleanups
- imported package enzo

